==> haskell-data-clist-0.1.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.1.0
id: data-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
key: data-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
license: BSD3
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
author: John Van Enk <vanenkj@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CircularList
abi: f662e1373618b30d0a636561a5a56e93
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-clist-0.1.1.0
hs-libraries: HSdata-clist-0.1.1.0-GTgxQ3fV2psCcWfrZtLEgz
depends:
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l base-4.10.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.1.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.1.0
id: data-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
key: data-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
license: BSD3
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
author: John Van Enk <vanenkj@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CircularList
abi: c6f6240cf9caddfee7636d74c5875403
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-clist-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-clist-0.1.1.0
hs-libraries: HSdata-clist-0.1.1.0-80fwGq2GOWoCmxNG1Z99T
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    deepseq-1.4.3.0
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
